
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
fi

( cd usr/share/doc/HTML/en/kmag ; rm -rf common )
( cd usr/share/doc/HTML/en/kmag ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmousetool ; rm -rf common )
( cd usr/share/doc/HTML/en/kmousetool ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmouth ; rm -rf common )
( cd usr/share/doc/HTML/en/kmouth ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/jovie ; rm -rf common )
( cd usr/share/doc/HTML/en/jovie ; ln -sf /usr/share/doc/HTML/en/common common )
